@@ -8,7 +8,7 @@ function(...) {
       "Now use  dens  instead of  color.density.\n",
     "<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<\n\n", sep="")
 
-  dens(...)
+  den(...)
 
   cat("\n"); cat( # stop(call.=FALSE, "\n","------\n",
     ">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>\n",
